# A simple implementation of unauthenticated ECDH

This package implements unauthenticated ECDH between two endpoints.
Authentication can then later be added by, for example, mutual short string
authentication (as exemplified by the simpleauthstrings package).

See [module](src/blindecdh/__init__.py) for more documentation.

This package is distributed under the GNU Lesser General Public License v2.1.
For relicensing, contact the package author.
